Index: src/wp-admin/css/edit.css
===================================================================
--- src/wp-admin/css/edit.css	(revision 42985)
+++ src/wp-admin/css/edit.css	(working copy)
@@ -694,6 +694,10 @@
 	border-left: 4px solid transparent;
 }
 
+.privacy-text-box-body .privacy-text-section:nth-child(odd):not(.text-removed):not(.text-updated) {
+	background-color: #f9f9f9;
+}
+
 .privacy-text-section.text-updated {
 	border-left-color: #46b450;
 	background-color: #ecf7ed;
@@ -704,6 +708,8 @@
 	background-color: #fbeaea;
 }
 
+.policy-text,
+.policy-text-less,
 .closed .privacy-text-box-body {
 	display: none;
 }
Index: src/wp-admin/includes/misc.php
===================================================================
--- src/wp-admin/includes/misc.php	(revision 42985)
+++ src/wp-admin/includes/misc.php	(working copy)
@@ -1569,16 +1569,20 @@
 
 			$content .= '<div class="privacy-text-section' . $class . '">';
 			$content .= '<h3>' . $section['plugin_name'] . '</h3>';
-			$content .= '<button type="button" class="privacy-text-copy-button button">';
-			$content .= $copy;
-			$content .= '<span class="screen-reader-text">' . sprintf( __( 'Copy suggested policy text from %s.' ), $section['plugin_name'] ) . '</span>';
-			$content .= '</button>';
 
+			if ( empty( $section['removed'] ) ) {
+				$content .= '<button type="button" class="privacy-text-copy-button button" disabled>';
+				$content .= $copy;
+				$content .= '<span class="screen-reader-text">' . sprintf( __( 'Copy suggested policy text from %s.' ), $section['plugin_name'] ) . '</span>';
+				$content .= '</button>';
+			}
+
 			if ( ! empty( $meta ) ) {
 				$content .= '<span class="privacy-text-meta">' . $meta . '</span>';
 			}
 
-			$content .= '<div class="policy-text">' . $section['policy_text'] . '</div>';
+			$content .= '<div class="policy-text">' . $section['policy_text'] . '</div><p><a href="#" class="policy-text-less">' . __( 'Read Less' ) . '</a></p>';
+			$content .= '<div class="policy-text-excerpt">' . substr( $section['policy_text'], 0, 400 ) . '&hellip;</div><p><a href="#" class="policy-text-more">' . __( 'Read More' ) . '</a></p>';
 			$content .= "</div>\n";
 		}
 
Index: src/wp-admin/js/post.js
===================================================================
--- src/wp-admin/js/post.js	(revision 42985)
+++ src/wp-admin/js/post.js	(working copy)
@@ -1268,7 +1268,12 @@
 		update();
 	} );
 
-	// Privacy policy postbox, copy button.
+} )( jQuery, new wp.utils.WordCounter() );
+
+
+// Privacy policy postbox, copy button, policy text read more, policy text read less.
+( function( $ ) {
+
 	$( document ).on( 'click', function( event ) {
 		var $target = $( event.target );
 		var node, range;
@@ -1288,6 +1293,22 @@
 				} catch ( er ) {}
 			}
 		}
+
+		if ( $target.is( 'a.policy-text-more' ) ) {
+			$target.toggle();
+			$target.parent().siblings('div.policy-text').toggle();
+			$target.parent().siblings('div.policy-text-excerpt').toggle();
+			$target.parent().parent().find('a.policy-text-less').toggle();
+			$target.parent().parent().find('.privacy-text-copy-button').prop( 'disabled', false ); 
+		}
+
+		if ( $target.is( 'a.policy-text-less' ) ) {
+			$target.toggle();
+			$target.parent().siblings( 'div.policy-text' ).toggle();
+			$target.parent().siblings( 'div.policy-text-excerpt' ).toggle();
+			$target.parent().parent().find('a.policy-text-more').toggle();
+			$target.parent().parent().find('.privacy-text-copy-button').prop( 'disabled', true ); 
+		}
 	});
 
-} )( jQuery, new wp.utils.WordCounter() );
+} )( jQuery );
